assert_nonzero_after

Function assert_nonzero_after 

pub fn assert_nonzero_after<P: PluginExport>(
    result: &DriverResult<P>,
    t: Duration,
)
Assert at least one sample after t is above the audible threshold.

Panics

Panics if every sample after t is at or below AUDIBLE_THRESHOLD.