pub fn assert_silence<P: PluginExport>(result: &DriverResult<P>)Expand description
Assert every sample in the output is below the audible threshold.
Panics
Panics if any sample’s absolute value is at or above
AUDIBLE_THRESHOLD (1e-3).
pub fn assert_silence<P: PluginExport>(result: &DriverResult<P>)Assert every sample in the output is below the audible threshold.
Panics if any sample’s absolute value is at or above
AUDIBLE_THRESHOLD (1e-3).