pub fn assert_has_editor<P: PluginExport>()Expand description
Assert the plugin has a working editor with valid dimensions.
Panics
Panics if Plugin::editor() returns None or the editor’s
reported size has a zero dimension.
pub fn assert_has_editor<P: PluginExport>()Assert the plugin has a working editor with valid dimensions.
Panics if Plugin::editor() returns None or the editor’s
reported size has a zero dimension.