assert_meter_above

Function assert_meter_above 

pub fn assert_meter_above<P: PluginExport>(
    result: &DriverResult<P>,
    id: u32,
    threshold: f32,
)
Assert the meter identified by id read above threshold at the end of the run.

Panics

Panics if no meter with id is in the result, the meter’s final value is at or below threshold, or CaptureSpec::meters was MeterCapture::None (call .capture_meters(MeterCapture::Final) on the driver).