pub fn assert_meter_below<P: PluginExport>(
result: &DriverResult<P>,
id: u32,
threshold: f32,
)Expand description
Assert the meter identified by id read below threshold at
the end of the run.
Panics
Panics if no meter with id is in the result, the meter’s
final value is at or above threshold, or
CaptureSpec::meters was MeterCapture::None.