pub fn assert_nonzero<P: PluginExport>(result: &DriverResult<P>)Expand description
Assert that at least one sample anywhere in the output is above the audible threshold.
Panics
Panics if every sample is at or below AUDIBLE_THRESHOLD (1e-3).
pub fn assert_nonzero<P: PluginExport>(result: &DriverResult<P>)Assert that at least one sample anywhere in the output is above the audible threshold.
Panics if every sample is at or below AUDIBLE_THRESHOLD (1e-3).