pub fn assert_param_defaults_match<P: PluginExport>()Expand description
Assert all parameter default values match their declared defaults.
Panics
Panics if get_plain returns None for an id that has a
ParamInfo entry (derive-macro inconsistency), or if the current
plain value differs from default_plain by more than 1e-4.